#!/bin/bash
#
# author           : Pedro Pinto (pnboy~AT~pinguix.com)
# latest update    : 26-02-2007
# source location  : http://wiki.services.openoffice.org/wiki/Dictionaries
# url              : http://ftp.services.openoffice.org/pub/OpenOffice.org/contrib/dictionaries/

ARCH=${ARCH:-noarch}
VERSION=${VERSION:-1.1.7}
BUILD=${BUILD:-48.1}
TMP=${TMP:-/tmp/hunspell/}
CWD=`pwd`
EXTENSION=zip

mkdir -p $TMP
cd $TMP
langs="af_ZA bg_BG ca_ES cs_CZ cy_GB da_DK de_AT de_CH de_DE el_GR en_AU en_CA en_GB-oed en_NZ en_US eo es_ES es_MX fo_FO fr_BE fr_FR ga_IE gd_GB gl_ES he_IL hr_HR hu_HU ia id_ID it_IT ku_TR la lt_LT mg_MG mi_NZ ms_MY nb_NO nl_NL nn_NO ny_MW pl_PL pt_BR pt_PT ro_RO ru_RU rw_RW sk_SK sl_SI sv_SE sw_KE tl_PH tn_ZA uk_UA zu_ZA"
if [ ! -f available.lst ]; then
	wget -c http://ftp.services.openoffice.org/pub/OpenOffice.org/contrib/dictionaries/available.lst || exit 1
fi

for lang in $langs; do
	cd $TMP
	if [ ! -f $lang.$EXTENSION ]; then
		wget -c http://ftp.services.openoffice.org/pub/OpenOffice.org/contrib/dictionaries/$lang.$EXTENSION || exit 1
	fi
	if [ ! -f thes_$lang.$EXTENSION ]; then
		wget -c http://ftp.services.openoffice.org/pub/OpenOffice.org/contrib/dictionaries/thes_$lang.$EXTENSION
	fi
	if [ ! -f hyph_$lang.$EXTENSION ]; then
		wget -c http://ftp.services.openoffice.org/pub/OpenOffice.org/contrib/dictionaries/hyph_$lang.$EXTENSION
	fi
	if [ -f $lang.$EXTENSION ]; then
		aux=`cat available.lst | grep ${lang%-*},`
		aux=`echo $aux | sed 's/ //g'`
		aux=`echo $aux | sed 's/,/\n/g'`
		alang=($aux)
		NAME=hunspell-${lang%-*}
		PKG=$TMP/package-$NAME-$VERSION
		mkdir -p $PKG/usr/share/myspell/
		cd $PKG
		unzip $TMP/$lang.$EXTENSION -d $PKG/usr/share/myspell/
		mkdir -p $PKG/install
		echo -e "if ! grep -qe \"^DICT.*${lang%-*}\" usr/share/myspell/dictionary.lst; then echo -n \"\\nDICT ${alang[0]} ${alang[1]} ${alang[2]}\" >> usr/share/myspell/dictionary.lst; fi">$PKG/install/doinst.sh
		if [ -f $TMP/thes_$lang.$EXTENSION ]; then
			unzip -o $TMP/thes_$lang.$EXTENSION -d $PKG/usr/share/myspell/
			echo -e "if ! grep -qe \"^THES.*${lang%-*}\" usr/share/myspell/dictionary.lst; then echo -n \"\\nTHES ${alang[0]} ${alang[1]} ${alang[2]}\" >> usr/share/myspell/dictionary.lst; fi">>$PKG/install/doinst.sh
		fi
		if [ -f $TMP/hyph_$lang.$EXTENSION ]; then
			unzip -o $TMP/hyph_$lang.$EXTENSION -d $PKG/usr/share/myspell/
			echo -e "if ! grep -qe \"^HYPH.*${lang%-*}\" usr/share/myspell/dictionary.lst; then echo -n \"\\nHYPH ${alang[0]} ${alang[1]} ${alang[2]}\" >> usr/share/myspell/dictionary.lst; fi">>$PKG/install/doinst.sh
		fi
# 
# as per package rules: add the build-file itself
#
		mkdir -p $PKG/usr/src/$NAME-$VERSION
		cp "$CWD/build-hunspell-langs.sh" "$PKG/usr/src/$NAME-$VERSION/build-hunspell-langs.sh"
		chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-hunspell-langs.sh"

		chmod +x $PKG/install/doinst.sh

#    |-----handy-ruler------------------------------------------------------|
		echo "\
$NAME: $NAME (${alang[3]/(/ (} dictionary for Hunspell)
$NAME:
$NAME: The ${alang[3]/(/ (} dictionary for Hunspell
$NAME:
$NAME:
$NAME:
$NAME:
$NAME:
$NAME:
$NAME:
$NAME:\
" > $PKG/install/slack-desc

#
# real packaging work:
#
# Make sure ownerships and permissions are sane:
		cd $PKG
		chown -R root:root .
		find . -perm 666 -exec chmod 644 {} \;
		find . -perm 664 -exec chmod 644 {} \;
		find . -perm 600 -exec chmod 644 {} \;
		find . -perm 444 -exec chmod 644 {} \;
		find . -perm 400 -exec chmod 644 {} \;
		find . -perm 440 -exec chmod 644 {} \;
		find . -perm 777 -exec chmod 755 {} \;
		find . -perm 775 -exec chmod 755 {} \;
		find . -perm 511 -exec chmod 755 {} \;
		find . -perm 711 -exec chmod 755 {} \;
		find . -perm 555 -exec chmod 755 {} \;
		makepkg -l y -c n ../$NAME-$VERSION-$ARCH-$BUILD.tgz

#
# computes the md5sum signature for the package
#
		cd $TMP
		md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5
		echo "gcc-g++,hunspell,ncurses" > $NAME-$VERSION-$ARCH-$BUILD.dep
	fi
done

